aboutsummaryrefslogtreecommitdiffstats
path: root/lang/js/BrowserTestExtension/tests/signTest.js
diff options
context:
space:
mode:
authorMaximilian Krambach <[email protected]>2018-07-27 09:20:33 +0000
committerMaximilian Krambach <[email protected]>2018-07-27 09:20:33 +0000
commitb18b96fb364711025d1e5fa9f135ee682dd0558a (patch)
tree9221b5b177eb68a7a11a66c1b782048aa61e3b3d /lang/js/BrowserTestExtension/tests/signTest.js
parentjs: include armored Key in import callback (diff)
downloadgpgme-b18b96fb364711025d1e5fa9f135ee682dd0558a.tar.gz
gpgme-b18b96fb364711025d1e5fa9f135ee682dd0558a.zip
js: clean up test extension
-- Tests will now run with one instance of gpgmejs each block, which reduces overhead. Readability is (hopefully) improved), some negative tests are added. There is still a performance problem in base64 encoding/decoding, which causes some tests to fail due to time out.
Diffstat (limited to 'lang/js/BrowserTestExtension/tests/signTest.js')
-rw-r--r--lang/js/BrowserTestExtension/tests/signTest.js58
1 files changed, 29 insertions, 29 deletions
diff --git a/lang/js/BrowserTestExtension/tests/signTest.js b/lang/js/BrowserTestExtension/tests/signTest.js
index ffd2d5de..2763dadf 100644
--- a/lang/js/BrowserTestExtension/tests/signTest.js
+++ b/lang/js/BrowserTestExtension/tests/signTest.js
@@ -21,42 +21,42 @@
* Maximilian Krambach <[email protected]>
*/
/* global describe, it, expect, Gpgmejs */
/* global bigString, inputvalues */
describe('Signing', function () {
+ let context = null;
+ const good_fpr = inputvalues.encrypt.good.fingerprint;
+
+ before(function(done){
+ const prm = Gpgmejs.init();
+ prm.then(function(gpgmejs){
+ context = gpgmejs;
+ done();
+ });
+ });
+
it('Sign a message', function (done) {
- let prm = Gpgmejs.init();
- prm.then(function (context) {
- let data = bigString(100);
- context.sign(
- data,
- inputvalues.encrypt.good.fingerprint).then(function (answer) {
- expect(answer).to.not.be.empty;
- expect(answer.data).to.be.a('string');
- expect(answer.data).to.include('BEGIN PGP SIGNATURE');
- expect(answer.data).to.include('END PGP SIGNATURE');
- expect(answer.data).to.include(data);
- done();
- });
+ const data = bigString(100);
+ context.sign(data, good_fpr).then(function (answer) {
+ expect(answer).to.not.be.empty;
+ expect(answer.data).to.be.a('string');
+ expect(answer.data).to.include('BEGIN PGP SIGNATURE');
+ expect(answer.data).to.include('END PGP SIGNATURE');
+ expect(answer.data).to.include(data);
+ done();
});
});
+
it('Detached sign a message', function (done) {
- let prm = Gpgmejs.init();
- prm.then(function (context) {
- let data = bigString(100);
- context.sign(
- data,
- inputvalues.encrypt.good.fingerprint,
- 'detached'
- ).then(function (answer) {
- expect(answer).to.not.be.empty;
- expect(answer.data).to.be.a('string');
- expect(answer.data).to.include(data);
- expect(answer.signature).to.be.a('string');
- expect(answer.signature).to.be.a('string');
- done();
- });
+ const data = bigString(100);
+ context.sign(data,good_fpr, 'detached').then(function (answer) {
+ expect(answer).to.not.be.empty;
+ expect(answer.data).to.be.a('string');
+ expect(answer.data).to.include(data);
+ expect(answer.signature).to.be.a('string');
+ expect(answer.signature).to.be.a('string');
+ done();
});
});
@@ -21,42 +21,42 @@
* Maximilian Krambach <[email protected]>
*/
-/* global describe, it, expect, Gpgmejs */
+/* global describe, it, expect, before, Gpgmejs */
/* global bigString, inputvalues */
describe('Signing', function () {